"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChangePasswordForm = void 0;
var react_1 = __importStar(require("react"));
var auth_shared_1 = require("../../auth-shared");
var Typography_1 = __importDefault(require("@mui/material/Typography"));
var Divider_1 = __importDefault(require("@mui/material/Divider"));
var styles_1 = require("@mui/material/styles");
var SecureTextField_1 = require("../SecureTextField");
var PasswordRequirements_1 = require("./PasswordRequirements");
var styles_2 = require("../../styles");
var CheckCircleOutlined_1 = __importDefault(require("@mui/icons-material/CheckCircleOutlined"));
var constants_1 = require("../../constants");
/**
 * Component that renders a change password form with a new password and confirm password inputs.
 * It includes callbacks so you can respond to changes in the inputs.
 *
 * @param onPasswordChange Fired when the new password or confirm new password fields value changes
 * @param initialPassword Value to initialize the password field
 * @param initialConfirm Value to initialize the confirm field
 * @param passwordLabel Optional label for the new password field (default = 'Password')
 * @param confirmLabel Optional label for the confirm password field (default = 'Confirm')
 * @param description Optional text to replace the instructional text above the password fields.
 * @param passwordRef Optional ref to forward to the password input.
 * @param confirmRef Optional ref to forward to the confirm password input.
 * @param onSubmit Optional callback function to call when the mini form is submitted.
 *
 * @category Component
 */
var ChangePasswordForm = function (props) {
    var onPasswordChange = props.onPasswordChange, _a = props.initialPassword, initialPassword = _a === void 0 ? '' : _a, _b = props.initialConfirm, initialConfirm = _b === void 0 ? '' : _b, passwordLabel = props.passwordLabel, confirmLabel = props.confirmLabel, description = props.description, children = props.children, passwordRef = props.passwordRef, confirmRef = props.confirmRef, onSubmit = props.onSubmit;
    var t = (0, auth_shared_1.useLanguageLocale)().t;
    var theme = (0, styles_1.useTheme)();
    // Local State
    var _c = (0, react_1.useState)(initialPassword), passwordInput = _c[0], setPasswordInput = _c[1];
    var _d = (0, react_1.useState)(initialConfirm), confirmInput = _d[0], setConfirmInput = _d[1];
    var _e = (0, react_1.useState)(false), shouldValidateConfirmPassword = _e[0], setShouldValidateConfirmPassword = _e[1];
    var _f = (0, react_1.useState)(false), shouldValidatePassword = _f[0], setShouldValidatePassword = _f[1];
    var onPassChange = (0, react_1.useCallback)(function (newPassword) {
        setPasswordInput(newPassword);
        onPasswordChange({ password: newPassword, confirm: confirmInput });
    }, [setPasswordInput, onPasswordChange, confirmInput]);
    var onConfirmChange = (0, react_1.useCallback)(function (newConfirm) {
        setConfirmInput(newConfirm);
        onPasswordChange({ password: passwordInput, confirm: newConfirm });
    }, [setConfirmInput, onPasswordChange, passwordInput]);
    var hasConfirmPasswordError = (0, react_1.useCallback)(function () { return shouldValidateConfirmPassword && confirmInput.length !== 0 && confirmInput !== passwordInput; }, [shouldValidateConfirmPassword, confirmInput, passwordInput]);
    var _g = (0, auth_shared_1.useInjectedUIContext)().passwordRequirements, passwordRequirements = _g === void 0 ? (0, constants_1.defaultPasswordRequirements)(t) : _g;
    var isValidPassword = (0, react_1.useCallback)(function () {
        for (var i = 0; i < passwordRequirements.length; i++) {
            if (!new RegExp(passwordRequirements[i].regex).test(passwordInput))
                return false;
        }
        return true;
    }, [passwordRequirements, passwordInput]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(Typography_1.default, null, description || t('blui:CHANGE_PASSWORD.PASSWORD_INFO')),
        react_1.default.createElement(Divider_1.default, { sx: (0, styles_2.FullDividerStyles)(theme) }),
        children,
        react_1.default.createElement(SecureTextField_1.SecureTextField, { id: "password", name: "password", inputRef: passwordRef, label: passwordLabel || t('blui:FORMS.PASSWORD'), value: passwordInput, onChange: function (evt) { return onPassChange(evt.target.value); }, sx: (0, styles_2.TextFieldStyles)(theme), onKeyPress: function (e) {
                if (e.key === 'Enter' && confirmRef.current) {
                    confirmRef.current.focus();
                }
            }, error: shouldValidatePassword && !isValidPassword(), onBlur: function () { return setShouldValidatePassword(true); } }),
        react_1.default.createElement(PasswordRequirements_1.PasswordRequirements, { sx: { mt: 2 }, passwordText: passwordInput }),
        react_1.default.createElement(SecureTextField_1.SecureTextField, { id: "confirm", name: "confirm", inputRef: confirmRef, label: confirmLabel || t('blui:FORMS.CONFIRM_PASSWORD'), sx: (0, styles_2.TextFieldStyles)(theme), value: confirmInput, onChange: function (evt) { return onConfirmChange(evt.target.value); }, onKeyPress: function (e) {
                if (e.key === 'Enter' && onSubmit)
                    onSubmit();
            }, error: hasConfirmPasswordError(), helperText: hasConfirmPasswordError() ? t('blui:FORMS.PASS_MATCH_ERROR') : '', icon: confirmInput.length !== 0 && confirmInput === passwordInput ? (react_1.default.createElement(CheckCircleOutlined_1.default, { color: "success" })) : undefined, onBlur: function () { return setShouldValidateConfirmPassword(true); } })));
};
exports.ChangePasswordForm = ChangePasswordForm;
