"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContactScreenBase = void 0;
var react_1 = __importDefault(require("react"));
var material_1 = require("@mui/material");
var WorkflowCard_1 = require("../../components/WorkflowCard");
var Box_1 = __importDefault(require("@mui/material/Box"));
var utilityClasses_1 = require("./utilityClasses");
var base_1 = require("@mui/base");
var styles_1 = require("../../styles");
/**
 * Component renders a screen with contact information for support with the application.
 * Contact information is pulled from the context passed into the workflow.
 *
 * @param title to display in the header
 * @param icon to display in the icon
 * @param emailSupportTitle to display the contact support title
 * @param emailSupportContent to display the contact support content
 * @param phoneSupportTitle to display the phone support title
 * @param phoneSupportContent to display the phone support content
 * @param contactEmail to display the contact email
 * @param contactPhone to display contact phone number
 * @param dismissButtonLabel to display label text in button
 * @param onDismiss function to call when user clicks button
 * @param slots used for each slot in `ContactScreen`
 * @param slotProps applied to each slot
 *
 * @category Component
 */
var useUtilityClasses = function (ownerState) {
    var classes = ownerState.classes;
    var slots = {
        root: ['root'],
        title: ['title'],
        icon: ['icon'],
        emailSupportTitle: ['emailSupportTitle'],
        emailSupportContent: ['emailSupportContent'],
        phoneSupportTitle: ['phoneSupportTitle'],
        phoneSupportContent: ['phoneSupportContent'],
        contactEmail: ['contactEmail'],
        contactPhone: ['contactPhone'],
        dismissButtonLabel: ['dismissButtonLabel'],
    };
    return (0, base_1.unstable_composeClasses)(slots, utilityClasses_1.getContactScreenUtilityClass, classes);
};
var ContactScreenBase = function (props) {
    var title = props.title, icon = props.icon, emailSupportTitle = props.emailSupportTitle, emailSupportContent = props.emailSupportContent, phoneSupportTitle = props.phoneSupportTitle, phoneSupportContent = props.phoneSupportContent, contactEmail = props.contactEmail, contactPhone = props.contactPhone, dismissButtonLabel = props.dismissButtonLabel, onDismiss = props.onDismiss;
    var defaultClasses = useUtilityClasses(props);
    var cardBaseProps = props.WorkflowCardBaseProps || {};
    var headerProps = props.WorkflowCardHeaderProps || {};
    var actionsProps = props.WorkflowCardActionsProps || {};
    return (react_1.default.createElement(WorkflowCard_1.WorkflowCard, __assign({}, cardBaseProps, { className: defaultClasses.root, "data-testid": defaultClasses.root }),
        react_1.default.createElement(WorkflowCard_1.WorkflowCardHeader, __assign({}, headerProps, { className: defaultClasses.title, "data-testid": defaultClasses.title, title: title || headerProps.title })),
        icon && (react_1.default.createElement(Box_1.default, { sx: { m: 3, mb: 5, textAlign: 'center' }, className: defaultClasses.icon }, icon)),
        react_1.default.createElement(WorkflowCard_1.WorkflowCardBody, null,
            react_1.default.createElement(material_1.Typography, { className: defaultClasses.emailSupportTitle, "data-testid": defaultClasses.emailSupportTitle, variant: "body1", sx: { mb: 1 } },
                ' ',
                emailSupportTitle),
            emailSupportContent && (react_1.default.createElement(material_1.Typography, { className: defaultClasses.emailSupportContent, "data-testid": defaultClasses.emailSupportContent, variant: "body1" },
                ' ',
                typeof emailSupportContent === 'string'
                    ? emailSupportContent
                    : emailSupportContent(contactEmail))),
            !emailSupportContent && (react_1.default.createElement(material_1.Typography, { className: defaultClasses.emailSupportContent, "data-testid": defaultClasses.emailSupportContent, variant: "body1" }, "For questions, feedback, or support please email us at ",
                react_1.default.createElement(material_1.Typography, { className: defaultClasses.contactEmail, "data-testid": defaultClasses.contactEmail, variant: "button", sx: __assign(__assign({}, styles_1.LinkStyles), { fontSize: 'inherit' }), component: "a", href: "mailto:".concat(contactEmail) }, contactEmail), ".")),
            react_1.default.createElement(material_1.Typography, { className: defaultClasses.phoneSupportTitle, "data-testid": defaultClasses.phoneSupportTitle, variant: "body1", sx: { mt: 4, mb: 1 } },
                ' ',
                phoneSupportTitle),
            phoneSupportContent && (react_1.default.createElement(material_1.Typography, { className: defaultClasses.phoneSupportContent, "data-testid": defaultClasses.phoneSupportContent, variant: "body1" },
                ' ',
                typeof phoneSupportContent === 'string'
                    ? phoneSupportContent
                    : phoneSupportContent(contactPhone))),
            !phoneSupportContent && (react_1.default.createElement(material_1.Typography, { className: defaultClasses.phoneSupportContent, "data-testid": defaultClasses.phoneSupportContent, variant: "body1" }, "For technical support, please call ",
                react_1.default.createElement(material_1.Typography, { className: defaultClasses.contactPhone, "data-testid": defaultClasses.contactPhone, variant: "button", sx: __assign(__assign({}, styles_1.LinkStyles), { fontSize: 'inherit' }), component: "a", href: "tel:".concat(contactPhone) }, contactPhone), "."))),
        react_1.default.createElement(material_1.Divider, null),
        react_1.default.createElement(WorkflowCard_1.WorkflowCardActions, __assign({}, actionsProps, { nextLabel: dismissButtonLabel || actionsProps.nextLabel, className: defaultClasses.dismissButtonLabel, onNext: function () {
                if (onDismiss)
                    onDismiss();
                if (actionsProps.onNext)
                    actionsProps.onNext();
            } }))));
};
exports.ContactScreenBase = ContactScreenBase;
